.. _all-salt.renderers:

=====================================
Full list of builtin renderer modules
=====================================

.. currentmodule:: salt.renderers

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    cheetah
    genshi
    gpg
    hjson
    jinja
    json
    mako
    msgpack
    py
    pydsl
    pyobjects
    stateconf
    wempy
    yaml
    yamlex
